@@ -699,6 +699,10 @@ ConsState(CONSENT *pCE)
 	    return "SSL_accept";
 	case INSSLSHUTDOWN:
 	    return "SSL_shutdown";
+#endif
+#if HAVE_GSSAPI
+	case INGSSACCEPT:
+	    return "GSSAPI_accept";
 #endif
 	case ISFLUSHING:
 	    return "flushing";
@@ -816,7 +820,7 @@ ConsInit(CONSENT *pCE)
      */
     if (pCE->fup) {
 	ConsDown(pCE, FLAGFALSE, FLAGTRUE);
-	usleep(250000);		/* pause 0.25 sec to let things settle a bit */
+	Sleep(250000);
     }
 
     pCE->autoReUp = 0;
@@ -881,8 +885,7 @@ ConsInit(CONSENT *pCE)
 #if HAVE_SETSOCKOPT
 		int one = 1;
 #endif
-
-		usleep(100000);	/* Not all terminal servers can keep up */
+		Sleep(100000);	/* Not all terminal servers can keep up */
 
 #if USE_IPV6
 # if HAVE_MEMSET
@@ -927,10 +930,11 @@ ConsInit(CONSENT *pCE)
 # endif
 			if (!SetFlags(cofile, O_NONBLOCK, 0))
 			    goto fail;
-			if ((ret =
-			     connect(cofile, rp->ai_addr,
-				     rp->ai_addrlen)) == 0)
+
+			ret = connect(cofile, rp->ai_addr, rp->ai_addrlen);
+			if (ret == 0 || errno == EINPROGRESS)
 			    goto success;
+
 		      fail:
 			close(cofile);
 		    }
