@@ -12,10 +12,12 @@
 # include <openssl/err.h>
 # if OPENSSL_VERSION_NUMBER < 0x10100000L
 #  define TLS_method SSLv23_method
+# endif/* OPENSSL_VERSION_NUMBER < 0x10100000L */
+# if (OPENSSL_VERSION_NUMBER < 0x10100000L) || defined(LIBRESSL_VERSION_NUMBER)
 #  define CIPHER_SEC0
 # else
 #  define CIPHER_SEC0 ":@SECLEVEL=0"
-# endif/* OPENSSL_VERSION_NUMBER < 0x10100000L */
+# endif/* OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER) */
 #endif
 #if HAVE_GSSAPI
 # include <gssapi/gssapi.h>
@@ -213,6 +215,7 @@ extern void ProcessSubst(SUBST *, char **, char **, char *, char *);
 extern char *MyVersion(void);
 extern unsigned int AtoU(char *);
 extern void StrCpy(char *, const char *, unsigned int);
+extern void Sleep(useconds_t);
 #if HAVE_OPENSSL
 extern SSL *FileGetSSL(CONSFILE *);
 extern void FileSetSSL(CONSFILE *, SSL *);
